lastfm library
LastFM Library. It contains different types you can find in LastFM.
Classes
- Album
- This object represents an album.
- AlbumSearchResults
- This object represents the AlbumSearchResults from a search.
- Artist
- This object represents an artist.
- ArtistSearchResults
- This object represents the ArtistSearchResults from a search.
- Attr
- This is a object that contains information about the response.
- Bio
- This object represents a bio.
- Chart
- This object represents a chart.
- Date
- This object represents a date. TODO: need to check if it's useful.
- Image
- This object represents an image.
- LibraryGetArtistsResponse
- This object represents a response about an artist library from a search.
- Link
- This object represents a link.
- NowPlaying
- This is a object that helps scrobbling multiple tracks.
- Registered
- This object represents a Registration, which contains a date ad a text. TODO: is this useful or it can be just a DateTime?
- Scrobble
- This is a object that helps scrobbling multiple tracks.
- Session
- This is a Session for Last FM.
- Stats
- This object represents the user stats of a determined LastFM object.
- Streamable
- This object represents a streamable object.
- Tag
- This object represents a tag.
- Taggings
- This object represents different type of applied tags in taggable objects.
- Track
- This object represents a track.
- TrackSearchResults
- This object represents the TrackSearchResults from a search.
- User
- This object represents a user.
- Wiki
- This object represents a wiki.
Enums
- Language
- List of different languages supported in LastFM methods.
- Period
- List of different periods used in LastFM methods.
- Size
- It's a list of different Size.
- TaggingType
-
Tagging type for
User.getPersonalTags.