Album class

This object represents an album.

Available extensions
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Album({String? title, String? name, Artist? artist, String? url, List<Image>? images, List<Track>? tracks, List<Tag>? tags, int? listeners, int? playCount, String? mbid})
Album.fromJson(Map<String, dynamic> json)
factory

Properties

artist ↔ Artist?
Artist of the album.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
images ↔ List<Image>?
A list of different size of the album cover.
getter/setter pair
listeners ↔ int?
The number of listeners of the album.
getter/setter pair
mbid ↔ String?
MusicBrainz ID.
getter/setter pair
name ↔ String?
Name of the album.
getter/setter pair
playCount ↔ int?
The number of plays of the album.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<Tag>?
A list of tags assigned to the album.
getter/setter pair
title ↔ String?
Title of the album.
getter/setter pair
tracks ↔ List<Track>?
A list of tracks of the album.
getter/setter pair
url ↔ String?
LastFM url of the album.
getter/setter pair

Methods

addTags({required List<String> tags}) → Future<bool>

Available on Album, provided by the AlbumExtension extension

AlbumMethods.addTags
getInfo({bool autoCorrect = false, String? username, Language language = Language.en}) → Future<Album>

Available on Album, provided by the AlbumExtension extension

AlbumMethods.getInfo
getTags({bool autoCorrect = false, String? user}) → Future<List<Tag>?>

Available on Album, provided by the AlbumExtension extension

AlbumMethods.getTags
getTopTags({bool autoCorrect = false}) → Future<List<Tag>?>

Available on Album, provided by the AlbumExtension extension

AlbumMethods.getTopTags
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTag({required String tag}) → Future<bool>

Available on Album, provided by the AlbumExtension extension

AlbumMethods.removeTag

Available on Album, provided by the AlbumExtension extension

AlbumMethods.search
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited