Image class

This object represents an image.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Image({Size? size, String? text})
Image.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size?
This is the size of the image. Check Size for more info.
getter/setter pair
text ↔ String?
The link of the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited