Period enum

List of different periods used in LastFM methods.

Inheritance
Available extensions

Values

WEEK → const Period
MONTH → const Period
MONTHS3 → const Period
MONTHS6 → const Period
YEAR → const Period
OVERALL → const Period

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String

Available on Period, provided by the PeriodExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Period>
A constant List of the values in this enum, in order of their declaration.