Scrobble class

This is a object that helps scrobbling multiple tracks.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Scrobble({required String track, String? album, required String artist, String? albumArtist, int? trackNumber, Duration? duration, DateTime? timestamp, String? context, String? streamId, bool? chosenByUser, String? mbid})
Scrobble.fromJson(Map<String, dynamic> json)
factory

Properties

album ↔ String?
The Album name to scrobble.
getter/setter pair
albumArtist ↔ String?
The album artist - if this differs from the track artist.
getter/setter pair
artist ↔ String
The Artist name to scrobble.
getter/setter pair
chosenByUser ↔ bool?
If the user chose this song, set on True, else (if the song was chosen by someone else, such as a radio station or recommendation service) set it to False.
getter/setter pair
context ↔ String?
Sub-client version (not public, only enabled for certain API keys).
getter/setter pair
duration ↔ Duration?
The duration of the Track to scrobble.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mbid ↔ String?
MusicBrainz ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId ↔ String?
The stream id for this track received from the radio.getPlaylist service, if scrobbling Last.fm radio.
getter/setter pair
timestamp ↔ DateTime?
The TimeStamp of the scrobble. If You're not doing strange stuff, you can use DateTime.now().
getter/setter pair
track ↔ String
The Track title to scrobble.
getter/setter pair
trackNumber ↔ int?
The track number of the Track to scrobble.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited