streamId property
The stream id for this track received from the radio.getPlaylist service, if scrobbling Last.fm radio.
Implementation
@JsonKey(name: 'streamId')
String? streamId;
The stream id for this track received from the radio.getPlaylist service, if scrobbling Last.fm radio.
@JsonKey(name: 'streamId')
String? streamId;