Tag class

This object represents a tag.

Available extensions
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Tag({required String name, String? url, int? count, int? total, int? reach, int? taggings, bool? streamable, Wiki? wiki})
Tag.fromJson(Map<String, dynamic> json)
factory

Properties

count ↔ int?
The usage number of the tag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
The tag name.
getter/setter pair
reach ↔ int?
The total number of usage of this tag.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamable ↔ bool?
If True, this tag can be used as a Radio Station.
getter/setter pair
taggings ↔ int?
The number of usage applied from a user.
getter/setter pair
total ↔ int?
The total number of usage of this tag from a user.
getter/setter pair
url ↔ String?
getter/setter pair
wiki ↔ Wiki?
The wiki of the tag.
getter/setter pair

Methods

getInfo({Language language = Language.en}) → Future<Tag>

Available on Tag, provided by the TagExtension extension

TagMethods.getInfo
getSimilar() → Future<List<Tag>?>

Available on Tag, provided by the TagExtension extension

TagMethods.getSimilar
getTopAlbums({int page = 1, int limit = 50}) → Future<List<Album>?>

Available on Tag, provided by the TagExtension extension

TagMethods.getTopAlbums
getTopArtists({int page = 1, int limit = 50}) → Future<List<Artist>?>

Available on Tag, provided by the TagExtension extension

TagMethods.getTopArtists
getTopTracks({int page = 1, int limit = 50}) → Future<List<Track>?>

Available on Tag, provided by the TagExtension extension

TagMethods.getTopTracks
getWeeklyChartList() → Future<List<Chart>?>

Available on Tag, provided by the TagExtension extension

TagMethods.getWeeklyChartList
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited