Taggings class

This object represents different type of applied tags in taggable objects.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Taggings({List<Album>? albums, List<Artist>? artists, List<Track>? tracks})
Taggings.fromJson(Map<String, dynamic> json)
factory

Properties

albums ↔ List<Album>?
A list of tagged albums.
getter/setter pair
artists ↔ List<Artist>?
A list of tagged artists.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracks ↔ List<Track>?
A list of tagged tracks.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited