TrackSearchResults class

This object represents the TrackSearchResults from a search.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TrackSearchResults({List<Track>? tracks, int? totalResults, int? statingIndex, int? itemsPerPage})
TrackSearchResults.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemsPerPage ↔ int?
Number of matches per page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statingIndex ↔ int?
A value that sign the starting index of the search.
getter/setter pair
totalResults ↔ int?
The number of generated matches from the search.
getter/setter pair
tracks ↔ List<Track>?
A list of matched tracks from the search.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited