Wiki class

This object represents a wiki.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Wiki({String? published, String? summary, String? content})
Wiki.fromJson(Map<String, dynamic> json)
factory

Properties

content ↔ String?
The real content of the wiki.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
published ↔ String?
The publication information of the wiki.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary ↔ String?
A brief summary of the wiki.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited