ArtistMethods class

This contains all the methods about an Artist.

Constructors

ArtistMethods(LastFM _api)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTags({required String artist, required List<String> tags}) → Future<bool>
Tag an artist with one or more user supplied tags.
getCorrection({required String artist}) → Future<List<Artist>>
Use the last.fm corrections data to check whether the supplied artist has a correction to a canonical artist
getInfo({String? artist, String? mbid, String? username, Language language = Language.en, bool autoCorrect = false}) → Future<Artist>
Get the metadata for an artist. Includes biography, truncated at 300 characters.
getSimilar({String? artist, String? mbid, int? limit, bool autoCorrect = false}) → Future<List<Artist>?>
Get all the artists similar to this artist.
getTags({String? artist, String? mbid, String? user, bool autoCorrect = false}) → Future<List<Tag>?>
Get the tags applied by an individual user to an artist on Last.fm. If accessed as an authenticated service /and/ you don't supply a user parameter then this service will return tags for the authenticated user. To retrieve the list of top tags applied to an artist by all users use artist.getTopTags.
getTopAlbums({String? artist, String? mbid, int page = 1, int limit = 50}) → Future<List<Album>?>
Get the top albums for an artist on Last.fm, ordered by popularity.
getTopTags({String? artist, String? mbid, bool autoCorrect = false}) → Future<List<Tag>?>
Get the top tags for an artist on Last.fm, ordered by popularity.
getTopTracks({String? artist, String? mbid, int page = 1, int limit = 50, bool autoCorrect = false}) → Future<List<Track>?>
Get the top tracks by an artist on Last.fm, ordered by popularity.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTag({required String artist, required String tag}) → Future<bool>
Remove a user's tag from an artist.
Search for an artist by name. Returns artist matches sorted by relevance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited