LibraryMethods class

This contains all the methods about a Library.

Constructors

LibraryMethods(LastFM _api)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArtists({required String user, int limit = 50, int? page}) → Future<LibraryGetArtistsResponse?>
A paginated list of all the artists in a user's library, with play counts and tag counts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited