UserMethods class
This contains all the methods about a User.
Constructors
- UserMethods(LastFM _api)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFriends(
{required String user, bool enableRecentTracks = false, int page = 1, int limit = 50}) → Future< List< User> ?> - Get a list of the user's friends on Last.fm.
-
getInfo(
{String? user}) → Future< User> - Get information about a user profile.
-
getLovedTracks(
{required String user, int page = 1, int limit = 50}) → Future< List< Track> ?> - Get the last 50 tracks loved by a user.
-
getPersonalTags(
{required String user, required String tag, required TaggingType taggingType, int page = 1, int limit = 50}) → Future< Taggings> - Get the user's personal tags.
-
getRecentTracks(
{required String user, int page = 1, int limit = 50, DateTime? fromDate, DateTime? toDate, bool extended = false}) → Future< List< Track> ?> - Get a list of the recent tracks listened to by this user.
-
getTopAlbums(
{required String user, Period? period, int page = 1, int limit = 50}) → Future< List< Album> ?> - Get the top albums listened to by a user. You can stipulate a time period. Sends the overall chart by default.
-
getTopArtists(
{required String user, Period? period, int page = 1, int limit = 50}) → Future< List< Artist> ?> - Get the top artists listened to by a user. You can stipulate a time period. Sends the overall chart by default.
-
getTopTags(
{required String user, int? limit}) → Future< List< Tag> ?> - Get the top tags used by this user.
-
getTopTracks(
{required String user, Period? period, int page = 1, int limit = 50}) → Future< List< Track> > - Get the top tracks listened to by a user. You can stipulate a time period. Sends the overall chart by default.
-
getWeeklyAlbumChart(
{required String user, DateTime? fromDate, DateTime? toDate}) → Future< List< Album> ?> - Get an album chart for a user profile, for a given date range. If no date range is supplied, it will return the most recent album chart for this user.
-
getWeeklyArtistChart(
{required String user, DateTime? fromDate, DateTime? toDate}) → Future< List< Artist> ?> - Get an artist chart for a user profile, for a given date range. If no date range is supplied, it will return the most recent artist chart for this user.
-
getWeeklyChartList(
{required String user}) → Future< List< Chart> ?> - Get a list of available charts for this user, expressed as date ranges which can be sent to the chart services.
-
getWeeklyTrackChart(
{required String user, DateTime? fromDate, DateTime? toDate}) → Future< List< Track> ?> - Get a track chart for a user profile, for a given date range. If no date range is supplied, it will return the most recent track chart for this user.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited