LastFMException class

It implements DioException class. You can find description that gives a brief information of what happened.

Implemented types

Constructors

LastFMException({required String errorCode, required String description, RequestOptions? requestOptions})
LastFMException.generate(dynamic errorObject, {RequestOptions? requestOptions})
factory

Properties

description → String
no setter
error → Object?
The original error/exception object; It's usually not null when type is DioExceptionType.unknown.
finalinherited
errorCode → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message that throws a DioException.
finalinherited
requestOptions → RequestOptions
The request info for the request that throws exception.
finalinherited
response → Response?
Response info, it may be null if the request can't reach to the HTTP server, for example, occurring a DNS error, network is not available.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stacktrace of the original error/exception object; It's usually not null when type is DioExceptionType.unknown.
finalinherited
stringBuilder ↔ DioExceptionReadableStringBuilder?
Each exception can be override with a customized builder or fallback to the default DioException.readableStringBuilder.
getter/setter pairinherited
type → DioExceptionType
finalinherited

Methods

copyWith({RequestOptions? requestOptions, Response? response, DioExceptionType? type, Object? error, StackTrace? stackTrace, String? message}) → DioException
Generate a new DioException by combining given values and original values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited