Bio class
This object represents a bio.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
- content ↔ String?
-
The real content of the bio.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
links
↔ List<
Link> ? -
A list of links.
getter/setter pair
- published ↔ String?
-
A string that indicates the date of publishing.
NOTE: it's a string and it can't be transformed into a Dart DateTime.
Because it's different between different bio.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary ↔ String?
-
A brief summary of the bio.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited