Registered class
This object represents a Registration, which contains a date ad a text. TODO: is this useful or it can be just a DateTime?
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- Registered({DateTime? unixTime, String? text})
-
Registered.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited