AlbumMethods class
This contains all the methods about an Album.
Constructors
- AlbumMethods(LastFM _api)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTags(
{required String artist, required String album, required List< String> tags}) → Future<bool> - Tag an album using a list of user supplied tags.
-
getInfo(
{String? artist, String? album, String? mbid, bool autoCorrect = false, String? username, Language language = Language.en}) → Future< Album> - Get the metadata and tracklist for an album on Last.fm using the album name or a musicbrainz id.
-
getTags(
{String? artist, String? album, String? mbid, bool autoCorrect = false, String? user}) → Future< List< Tag> ?> - Get the tags applied by an individual user to an album on Last.fm. To retrieve the list of top tags applied to an album by all users use album.getTopTags.
-
getTopTags(
{String? artist, String? album, String? mbid, bool autoCorrect = false}) → Future< List< Tag> ?> - Get the top tags for an album on Last.fm, ordered by popularity.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeTag(
{required String artist, required String album, required String tag}) → Future< bool> - Remove a user's tag from an album.
-
search(
{required String album, int page = 1, int limit = 30}) → Future< AlbumSearchResults> - Search for an album by name. Returns album matches sorted by relevance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited