ChartMethods class
This contains all the methods about a Chart.
Constructors
- ChartMethods(LastFM _api)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getTopArtists(
{int page = 1, int limit = 50}) → Future< List< Artist> ?> - Get the top artists chart.
-
getTopTags(
{int page = 1, int limit = 50}) → Future< List< Tag> ?> - Get the top tags chart.
-
getTopTracks(
{int page = 1, int limit = 50}) → Future< List< Track> ?> - Get the top tracks chart.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited