GeoMethods class

This contains all the methods about an Geo.

Constructors

GeoMethods(LastFM _api)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTopArtists({required String country, int page = 1, int limit = 50}) → Future<List<Artist>?>
Get the most popular artists on Last.fm by country.
getTopTracks({required String country, String? location, int page = 1, int limit = 50}) → Future<List<Track>>
Get the most popular tracks on Last.fm last week by country.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited