TagMethods class
This contains all the methods about a Tag.
Constructors
- TagMethods(LastFM _api)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInfo(
{required String tag, Language language = Language.en}) → Future< Tag> - Get the metadata for a tag.
-
getSimilar(
{required String tag}) → Future< List< Tag> ?> - Search for tags similar to this one. Returns tags ranked by similarity, based on listening data.
-
getTopAlbums(
{required String tag, int page = 1, int limit = 50}) → Future< List< Album> ?> - Get the top albums tagged by this tag, ordered by tag count.
-
getTopArtists(
{required String tag, int page = 1, int limit = 50}) → Future< List< Artist> ?> - Get the top artists tagged by this tag, ordered by tag count.
-
getTopTags(
) → Future< List< Tag> ?> - Fetches the top global tags on Last.fm, sorted by popularity (number of times used).
-
getTopTracks(
{required String tag, int page = 1, int limit = 50}) → Future< List< Track> ?> - Get the top tracks tagged by this tag, ordered by tag count.
-
getWeeklyChartList(
{required String tag}) → Future< List< Chart> ?> - Get a list of available charts for this tag, expressed as date ranges which can be sent to the chart services.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited